================
Litestar Granian
================

Litestar Granian is a plugin to run a Litestar application with the Granian ASGI server.


Installation
------------

Installing ``litestar-granian`` is as easy as calling your favorite Python package manager:

.. tab-set::

    .. tab-item:: pip
        :sync: key1

        .. code-block:: bash
            :caption: Using pip

            python3 -m pip install litestar-granian

    .. tab-item:: pdm

        .. code-block:: bash
            :caption: Using `PDM <https://pdm.fming.dev/>`_

            pdm add litestar-granian

    .. tab-item:: Poetry

        .. code-block:: bash
            :caption: Using `Poetry <https://python-poetry.org/>`_

            poetry add litestar-granian

Usage
-----

.. todo:: Add usage instructions

.. toctree::
    :titlesonly:
    :caption: Litestar Granian Documentation
    :hidden:

    usage/index
    reference/index

.. toctree::
    :titlesonly:
    :caption: Development
    :hidden:

    changelog
    contribution-guide
